# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from .models import Bank, BankDetail


class BankInline(admin.StackedInline):
    model = Bank
    extra = 0
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('int_code', 'cin',),
                ('abi', 'cab',), 'cc', 'note',
            )
        }),
        (_('visualization admin'), {
            'fields': ('status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'int_code', 'cin', 'abi', 'cab', 'cc',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class BankAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'organization', ('abi', 'cab',),
                ('int_code', 'cin',), 'cc', 'get_detail_bank',
            )
        }),
        (_('note'), {
            'fields': ('note',),
        }),
        (_('visualization admin'), {
            'fields': ('status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'organization',
        'abi', 'cab', 'int_code', 'cin', 'cc',
    )
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
        'get_detail_bank',
    )


class BankDetailAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('abi', 'cab',),
                ('name', 'agency',),
                'address', 'zip_code', 'locality', 'province', 'country'
            )
        }),
        (_('visualization admin'), {
            'fields': ('status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'abi', 'cab', 'name', 'agency', 'address',
        'zip_code', 'locality', 'province',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    search_fields = ('abi', 'cab', 'name',)

admin.site.register(Bank, BankAdmin)
admin.site.register(BankDetail, BankDetailAdmin)
