# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel

from thux.l10n.models import Country
from thux.organization.models import Organization


@python_2_unicode_compatible
class Bank(DateModel, UserModel, StatusModel):
    """
    Store banks
    MODELS:
    :model: `organization.Organization`
    """
    organization = models.ForeignKey(
        Organization,
        related_name='banks',
        verbose_name=_("organization"),
    )
    abi = models.CharField(
        max_length=5,
        db_index=True,
        verbose_name=_("ABI"),
    )
    cab = models.CharField(
        max_length=5,
        db_index=True,
        verbose_name=_("CAB"),
    )
    int_code = models.CharField(
        max_length=4,
        blank=True,
        verbose_name=_("int code")
    )
    cin = models.CharField(
        max_length=1,
        blank=True,
        verbose_name=_("CIN")
    )
    cc = models.CharField(
        max_length=12,
        blank=True,
        verbose_name=_("CC")
    )
    note = models.TextField(
        max_length=255,
        blank=True,
        verbose_name=_("note"),
    )

    class Meta:
        verbose_name = _("bank")
        verbose_name_plural = _("banks")
        ordering = ('abi', 'cab')
        permissions = (
            ("list_bank", "Can list bank"),
            ("detail_bank", "Can detail bank"),
            ("disable_bank", "Can disable bank"),
        )

    def __str__(self):
        return self.iban

    def get_iban(self):
        """
        Return IBAN
        """
        return str(self.int_code) + str(self.cin) + str(self.abi) + str(self.cab) + str(self.cc)

    iban = property(get_iban)

    def get_detail_bank(self):
        """
        Return an object DetailBank with abi and cab of Bank
        """
        try:
            return BankDetail.objects.get(abi=self.abi, cab=self.cab)
        except:
            return None


@python_2_unicode_compatible
class BankDetail(DateModel, UserModel, StatusModel):
    abi = models.CharField(
        max_length=5,
        db_index=True,
        verbose_name=_("ABI"),
    )
    cab = models.CharField(
        max_length=5,
        db_index=True,
        verbose_name=_("CAB"),
    )
    name = models.CharField(
        max_length=100,
        db_index=True,
        verbose_name=_("name"),
    )
    agency = models.CharField(
        max_length=100,
        db_index=True,
        verbose_name=_("agency"),
    )
    address = models.CharField(
        max_length=100,
        db_index=True,
        verbose_name=_("address"),
    )
    zip_code = models.CharField(
        max_length=5,
        db_index=True,
        verbose_name=_("zip code"),
    )
    locality = models.CharField(
        max_length=100,
        db_index=True,
        verbose_name=_("locality"),
    )
    province = models.CharField(
        max_length=2,
        db_index=True,
        verbose_name=_("province"),
    )
    country = models.ForeignKey(
        Country,
        db_index=True,
        default=108,  # id of Italy Country
        verbose_name=_("country"),
    )

    class Meta:
        verbose_name = _("bank detail")
        verbose_name_plural = _("bank details")
        ordering = ('abi', 'cab')
        unique_together = (('abi', 'cab'),)
        permissions = (
            ("list_bankdetail", "Can list bank detail"),
            ("detail_bankdetail", "Can detail bank detail"),
            ("disable_bankdetaily", "Can disable bank detail"),
        )

    def __str__(self):
        return "{} {}".format(self.abi, self.cab)
